@@ -6,8 +6,8 @@ regex = re.compile(r'Run "(.*)" instead')
 
 @for_app('yarn', at_least=1)
 def match(command):
-    return regex.findall(command.stderr)
+    return regex.findall(command.output)
 
 
 def get_new_command(command):
-    return regex.findall(command.stderr)[0]
+    return regex.findall(command.output)[0]
